<!--
 * @Author: yuyanget 845262968@qq.com
 * @Date: 2024-10-18 13:02:23
 * @LastEditors: yuyanget 845262968@qq.com
 * @LastEditTime: 2024-10-22 20:07:07
 * @FilePath: /xy_work/README.md
 * @Description: 这是默认设置,请设置`customMade`, 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
-->
# xy_work

- [简体中文](readme/README_zh_CN.md)
- [繁体中文](readme/README_zh_TW.md)
- [English](readme/README_en.md)

## 说明
通用工作模块.

## 源码仓库

- <a href="https://github.com/xy-base/xy_work.git" target="_blank">Github地址</a>  
- <a href="https://gitee.com/xy-base/xy_work.git" target="_blank">Gitee地址</a>

## 安装

```bash
pip install xy_work
```

## 使用

```bash
xy_work -h
# usage: xy_work [-h] [-c [{project,runner}]]
#
# >>>>>>>>>>>> xy_work - v1.0.1 <<<<<<<<<<<<<
#
# options:
#  -h, --help            show this help message and exit
#  -c [{project,runner}], --command [{project,runner}]
#                        命令: -----project => 项目 -----runner => 运行启动器
# 请输入 -c/--command 命令参数

xy_work -n xy_test_work -c project
# 创建项目 [ xy_test_work ] 成功!!!
# 项目路径 ==>>> /mnt/bs-media/Workspace/project/opensource/xy-base/xy_work/test/xy_test_work

cd xy_test_work

xy_work
# >>>>>>>>>>>> xy_test_work - v1.0.1 <<<<<<<<<<<<<
# Hello World!!!

```

## 捐赠

如果小伙伴们觉得这些工具还不错的话，能否请咱喝一杯咖啡呢?  

![Pay-Total](./readme/Pay-Total.png)


## 联系方式

```
微信: yuyangiit
邮箱: 845262968@qq.com
```